@@ -20,12 +20,11 @@ import unittest
 
 def test_suite():
     names = [
-        "debian",
-        "guess",
-        "upstream_ontologist",
+        "data",
         "vcs",
     ]
     module_names = [__name__ + ".test_" + name for name in names]
     module_names.append(__name__ + ".test_readme.test_suite")
+    module_names.append(__name__ + ".testdata.test_suite")
     loader = unittest.TestLoader()
     return loader.loadTestsFromNames(module_names)
